import java.io.IOException;

import org.jrobin.core.RrdDb;
import org.jrobin.core.RrdException;

public class DumpJRB {
	public static void main(String[] args) {
		String mode, inFile, outFile;

		if (args.length != 3)
			usage();

		mode = args[0];
		inFile = args[1];
		outFile = args[2];

		if (mode.equals("-import")) {
			importFile(inFile, outFile);
		} else if (mode.equals("-export")) {
			exportFile(inFile, outFile);
		} else {
			usage();
		}
	}

	public static void importFile(String inFile, String outFile) {
		RrdDb jrb;
		try {
			jrb = new RrdDb(outFile, inFile);
		} catch (IOException ioe) {
			System.err.println("Caught IOException: " + ioe.getMessage());
			System.exit(1);
		} catch (RrdException rrde) {
			System.err.println("Caught RrdException: " + rrde.getMessage());
			System.exit(1);
		}
	}

	public static void exportFile(String inFile, String outFile) {
		RrdDb jrb;
		try {
			jrb = new RrdDb(inFile);
			jrb.dumpXml(outFile);
		} catch (IOException ioe) {
			System.err.println("Caught IOException: " + ioe.getMessage());
			System.exit(1);
		} catch (RrdException rrde) {
			System.err.println("Caught RrdException: " + rrde.getMessage());
			System.exit(1);
		}
	}

	public static void usage() {
		System.err.println("Usage:  DumpJRB [-import|-export] [in-pathname] [out-pathname]");
		System.err.println();
		System.err.println("In import mode, in-pathname is an XML file and out-pathname is a JRobin data file.");
		System.err.println("In export mode, in-pathname is a JRobin data file and out-pathname is an XML file.");
		System.exit(1);
	}
}
